from libcpp.string cimport string
from libcpp.vector cimport vector

cdef extern from "rss/Feed.h" namespace "curata::rss":
    cdef struct FeedItem:
        string title
        string title_type
        string link
        string description
        string description_type
        string author
        string author_email
        string pubDate
        string guid
        string enclosure_url
        string enclosure_type
        string content_encoded
        string itunes_summary
        string base
        vector[string] labels
        vector[string] categories

    cdef struct Feed:
        string encoding
        string title
        string title_type
        string description
        string link
        string language
        string managingEditor
        string dc_creator
        string pubDate
        vector[FeedItem] items


cdef extern from "rss/parsers/FeedParser.h" namespace "curata::rss::parsers":
    cdef cppclass FeedParser:
        Feed parseFeed(const string& xmlText) except+



import os
from distutils.core import setup, Extension

OPTIMIZED = '-O2'
UNOPTIMIZED = '-O0'
OPTIMIZATION = OPTIMIZED


def root_rel(fpath):
    here = os.path.dirname(os.path.realpath(__file__))
    return os.path.join(here, fpath)


EXTRA_SRC = (
    'parsers/atom.cpp',
    'parsers/FeedParser.cpp',
    'parsers/rss09x.cpp',
    'parsers/rss10.cpp',
    'parsers/rss20.cpp',
    'parsers/pugi_util.cpp',
    'parsers/time_util.cpp',
    'parsers/url_util.cpp',
    'xml/pugixml.cpp',
    'util.cpp',
    'exceptions.cpp'
)

CY_SRC = (
    'cyrss/feed_parser/feed_parser.cpp',
    'cyrss/feed_parser/compat.cpp',
    'cyrss/feed_parser/benchmarker.cpp'
)

def get_extension():
    extra_src = map(lambda f: os.path.join('src', f), EXTRA_SRC)
    extra_src = list(map(root_rel, extra_src))
    all_src = list(CY_SRC) + extra_src
    return Extension('cyrss.feed_parser.feed_parser',
        sources=all_src,
        language='c++',
        include_dirs=[root_rel('include')],
        extra_compile_args=['--std=c++11', OPTIMIZATION]
    )


setup(
    name='cyrss',
    version='0.9.1',
    description="A fast RSS parser",
    license='MIT',
    package_data={
        'cyrss': ['*.py', '*.pxd', '*.hpp', '*.h', '*.cpp', '*.c'],
        'cyrss.feed_parser': ['*.py', '*.pxd', '*.hpp', '*.h', '*.cpp', '*.c']
    },
    packages=[
        'cyrss', 'cyrss.feed_parser'
    ],
    install_requires=['cchardet>=1.0.0'],
    ext_modules=[get_extension()],
    provides=['cyrss']
)
